@@ -7,8 +7,10 @@ use 5.016;
 
 use DBI qw();
 
+use App::DBBrowser::Auxil;
 use App::DBBrowser::Credentials;
 
+
 sub new {
     my ( $class, $info, $opt ) = @_;
     my $sf = {
@@ -27,7 +29,10 @@ sub get_db_driver {
 
 sub get_db_handle {
     my ( $sf, $db ) = @_;
+    my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, {} );
     my $cred = App::DBBrowser::Credentials->new( $sf->{i}, $sf->{o} );
+    my $attr = $ax->clone_data( $sf->{o}{connect_attr} );
+    delete $attr->{odbc_to_rdbms};
     my $dsn = "dbi:ODBC:DSN=$db";
     my $show_sofar = 'DSN '. $db;
     my $user = $cred->get_login( 'user', $show_sofar );
@@ -38,7 +43,7 @@ sub get_db_handle {
         RaiseError => 1,
         AutoCommit => 1,
         ShowErrorStatement => 1,
-        %{$sf->{o}{connect_attr}//{}}, ##
+        %{$attr//{}}, ##
     } );
     return $dbh;
 }
