@@ -452,8 +452,9 @@ sub __add_frame_clause {
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $ext = App::DBBrowser::Table::Extensions->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $tc = Term::Choose->new( $sf->{i}{tc_default} );
+    my $dbms = $sf->{i}{dbms};
     my @frame_clause_modes = ( 'ROWS', 'RANGE' );
-    if ( $sf->{i}{driver} =~ /^(?:SQLite|Pg|DuckDB|Oracle)\z/ ) {
+    if ( $dbms =~ /^(?:SQLite|Pg|DuckDB|Oracle)\z/ ) {
         push @frame_clause_modes, 'GROUPS';
     }
     if ( ! length $win_data->{$frame_mode} ) {
@@ -492,7 +493,7 @@ sub __add_frame_clause {
             my @pre = ( undef, $confirm );
             my ( $frame_start, $frame_end, $frame_exclusion ) = ( '- Add Frame start', '- Add Frame end', '- Add Frame exclusion' );
             my $menu = [ @pre, $frame_start, $frame_end ];
-            if ( $sf->{i}{driver} =~ /^(?:SQLite|Pg|DuckDB|Oracle)\z/ ) {
+            if ( $dbms =~ /^(?:SQLite|Pg|DuckDB|Oracle)\z/ ) {
                 push @$menu, $frame_exclusion;
             }
             $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data, $frame_mode ) ];
@@ -543,11 +544,11 @@ sub __add_frame_start_or_end {
     my $tc = Term::Choose->new( $sf->{i}{tc_default} );
     my ( @frame_point_types, $prompt );
     if ( $pos eq $frame_start ) {
-        @frame_point_types = ( 'UNBOUNDED PRECEDING', 'n PRECEDING', 'CURRENT ROW', 'n FOLLOWING' );
+        @frame_point_types = ( 'UNBOUNDED PRECEDING', 'n PRECEDING', 'CURRENT ROW', 'n FOLLOWING' ); # ###
         $prompt = 'Frame start:';
     }
     elsif ( $pos eq $frame_end ) {
-        @frame_point_types = ( 'n PRECEDING', 'CURRENT ROW', 'n FOLLOWING', 'UNBOUNDED FOLLOWING' );
+        @frame_point_types = ( 'n PRECEDING', 'CURRENT ROW', 'n FOLLOWING', 'UNBOUNDED FOLLOWING' ); # ###
         $prompt = 'Frame end:';
     }
     my $info_sql = $ax->get_sql_info( $sql );
